==> text_explainability-0.6.0.tar.gz: text_explainability-0.6.0/text_explainability/test/test_global_explanation.py <==
import pytest

from text_explainability.generation.return_types import FeatureList
from text_explainability.global_explanation import (TokenFrequency,
                                                    TokenInformation)
from text_explainability.test.__test import TEST_ENVIRONMENT, TEST_MODEL

METHODS = [TokenFrequency, TokenInformation]


@pytest.mark.parametrize('method', METHODS)
@pytest.mark.parametrize('labelprovider', [None, TEST_ENVIRONMENT.labels])
def test_requires_model(method, labelprovider):
    with pytest.raises(ValueError):
        method(TEST_ENVIRONMENT.dataset).__call__(model=None, labelprovider=labelprovider, explain_model=True), 'No model but still forms explanation'

@pytest.mark.parametrize('method', METHODS)
@pytest.mark.parametrize('model', [None, TEST_MODEL])
def test_requires_labelprovider(method, model):
    with pytest.raises(ValueError):
        method(TEST_ENVIRONMENT.dataset).__call__(model=model, labelprovider=None, explain_model=False), 'No labelprovider but still forms explanation'

@pytest.mark.parametrize('method', METHODS)
@pytest.mark.parametrize('explain_model', [True, False])
def test_return_type(method, explain_model):
    assert isinstance(method(TEST_ENVIRONMENT.dataset).__call__(model=TEST_MODEL,
                                                                labelprovider=TEST_ENVIRONMENT.labels,
                                                                explain_model=explain_model),
                      FeatureList), 'Wrong return type'

==> text_explainability-0.6.7.tar.gz: text_explainability-0.6.7/text_explainability/test/test_global_explanation.py <==
import pytest

from text_explainability.generation.return_types import FeatureList
from text_explainability.global_explanation import TokenFrequency, TokenInformation
from text_explainability.test.__test import TEST_ENVIRONMENT, TEST_MODEL

METHODS = [TokenFrequency, TokenInformation]


@pytest.mark.parametrize('method', METHODS)
@pytest.mark.parametrize('labelprovider', [None, TEST_ENVIRONMENT.labels])
def test_requires_model(method, labelprovider):
    with pytest.raises(ValueError):
        method(TEST_ENVIRONMENT.dataset).__call__(model=None, labelprovider=labelprovider, explain_model=True), 'No model but still forms explanation'

@pytest.mark.parametrize('method', METHODS)
@pytest.mark.parametrize('model', [None, TEST_MODEL])
def test_requires_labelprovider(method, model):
    with pytest.raises(ValueError):
        method(TEST_ENVIRONMENT.dataset).__call__(model=model, labelprovider=None, explain_model=False), 'No labelprovider but still forms explanation'

@pytest.mark.parametrize('method', METHODS)
@pytest.mark.parametrize('explain_model', [True, False])
def test_return_type(method, explain_model):
    assert isinstance(method(TEST_ENVIRONMENT.dataset).__call__(model=TEST_MODEL,
                                                                labelprovider=TEST_ENVIRONMENT.labels,
                                                                explain_model=explain_model),
                      FeatureList), 'Wrong return type'

@pytest.mark.parametrize('method', METHODS)
@pytest.mark.parametrize('explain_model', [True, False])
@pytest.mark.parametrize('filter_words', [['een'], ['een', '']])
def test_filter_words(method, explain_model, filter_words):
    res = method(TEST_ENVIRONMENT.dataset).__call__(model=TEST_MODEL,
                                                    labelprovider=TEST_ENVIRONMENT.labels,
                                                    explain_model=explain_model,
                                                    filter_words=filter_words)
    assert all(token not in filter_words for token in res.scores.values()), 'Tokens not properly filtered'
